borderRadius property
Optional shape override for design systems that use less-rounded badges.
Defaults to the theme pill radius for backwards compatibility.
Implementation
final BorderRadius? borderRadius;
Optional shape override for design systems that use less-rounded badges.
Defaults to the theme pill radius for backwards compatibility.
final BorderRadius? borderRadius;