UiBootstrapPalette class abstract final

Bootstrap 5.3 base color anchors for direct migration.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

blue → const Color
cyan → const Color
green → const Color
indigo → const Color
orange → const Color
pink → const Color
purple → const Color
red → const Color
teal → const Color
yellow → const Color