moreLabel property

String? moreLabel
final

Label used by the automatic overflow control and default overflow drawer.

Defaults to UiLocalizations.more. Apps with their own localization system can pass a resolved string here without replacing the whole overflow drawer.

Implementation

final String? moreLabel;