UiContainerTransformTransition class

Geometry and reveal primitive used by UiContainerTransformRoute.

The destination remains laid out at its final size. Only paint-time clip, surface geometry, and opacity change during the transition.

Inheritance

Constructors

UiContainerTransformTransition({Key? key, required Animation<double> animation, required Rect sourceRect, required Color surfaceColor, required Color scrimColor, required Size sourceSize, required Widget child, Animation<double>? phaseAnimation, Widget? sourceChild, BorderRadius sourceBorderRadius = BorderRadius.zero, BorderRadius destinationBorderRadius = BorderRadius.zero, double contentRevealStart = 0.20, double contentRevealEnd = 0.42})
const

Properties

animation Animation<double>
final
child Widget
final
contentRevealEnd double
final
contentRevealStart double
final
destinationBorderRadius BorderRadius
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
phaseAnimation Animation<double>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrimColor Color
final
sourceBorderRadius BorderRadius
final
sourceChild Widget?
final
sourceRect Rect
final
sourceSize Size
final
surfaceColor Color
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited