UiContourOvershootPolicy enum
How a UiContourPhysics response may deform past its resting geometry.
Values
- none → const UiContourOvershootPolicy
-
The response never exceeds its resting value. Used for chrome and destructive/high-stakes actions.
- subtle → const UiContourOvershootPolicy
-
The response may deform by a small, clamped amount before settling. Used for ordinary controls and surfaces.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UiContourOvershootPolicy> - A constant List of the values in this enum, in order of their declaration.