settleThreshold property
The progress value, once reached, past which the response is considered visually settled.
Implementation
final double settleThreshold;
The progress value, once reached, past which the response is considered visually settled.
final double settleThreshold;