UiDataTable class

Inheritance

Constructors

UiDataTable({Key? key, required List<UiDataColumn> columns, required List<UiDataRow> rows, bool loading = false, String? errorText, VoidCallback? onRetry, String emptyText = 'No records yet.', int lazyRowThreshold = 50, double maxBodyHeight = 360, double rowExtent = 44, bool scrollable = true})
const
UiDataTable.lazy({Key? key, required List<UiDataColumn> columns, required int? rowCount, required UiDataRowBuilder? rowBuilder, bool loading = false, String? errorText, VoidCallback? onRetry, String emptyText = 'No records yet.', double maxBodyHeight = 360, double rowExtent = 44, bool scrollable = true})
const

Properties

columns List<UiDataColumn>
final
emptyText String
final
errorText String?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lazyRowThreshold int
final
loading bool
final
maxBodyHeight double
final
onRetry VoidCallback?
final
rowBuilder UiDataRowBuilder?
final
rowCount int?
final
rowExtent double
final
rows List<UiDataRow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
Whether the table body owns a height-capped vertical scroll view.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited