UiFormatAction class
Constructors
- UiFormatAction({required String ruleId, required String label, required String shortLabel})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- ruleId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortLabel → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
defaults
→ const List<
UiFormatAction>