UiIntent enum

Semantic emphasis shared by intent-aware UI components.

Components may interpret defaultIntent differently. For example, buttons use a primary default while passive status surfaces use a neutral default.

Inheritance
Available extensions

Values

defaultIntent → const UiIntent
neutral → const UiIntent
primary → const UiIntent
secondary → const UiIntent
destructive → const UiIntent
danger → const UiIntent
ghost → const UiIntent

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UiIntent>
A constant List of the values in this enum, in order of their declaration.