UiMenuItem class

Single actionable row in the menu.

Inheritance

Constructors

UiMenuItem({required String label, FutureOr<void> onPressed()?, Widget? leading, UiMenuShortcut? shortcut, bool enabled = true, bool destructive = false, bool loading = false})
const

Properties

destructive bool
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
leading Widget?
final
loading bool
final
onPressed FutureOr<void> Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut UiMenuShortcut?
Optional trailing shortcut glyph (e.g. UiMenuShortcut('⌘K')).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited