onDismiss property
Requests dismissal of the caller-owned root overlay. Without a callback, the bounded stack returns to its root page.
Implementation
final VoidCallback? onDismiss;
Requests dismissal of the caller-owned root overlay. Without a callback, the bounded stack returns to its root page.
final VoidCallback? onDismiss;