UiMenuTokens class
Menu-specific surface and interaction tokens. Colors, spacing, typography and radii resolve from the shared theme palettes.
- Annotations
Constructors
- UiMenuTokens({double surfaceOpacity = .84, double borderOpacity = .18, double borderWidth = .5, Color? borderColor, double backdropBlurSigma = 16, double parentScale = .96, double scrimOpacity = .24, double maxHeight = 420, double iconSize = 17, double pressExpansion = .15, double springStrength = .25, double travelArc = 24, double rowPaddingVertical = 8, double rowPaddingHorizontal = 10, double rowMinHeight = 36, Duration closeDuration = const Duration(milliseconds: 280), })
-
const
Properties
- backdropBlurSigma → double
-
final
- borderColor → Color?
-
Exact outline color override, including alpha. Null uses the foreground
color with borderOpacity.
final
- borderOpacity → double
-
final
- borderWidth → double
-
final
- closeDuration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- iconSize → double
-
final
- maxHeight → double
-
final
- parentScale → double
-
final
- pressExpansion → double
-
final
- rowMinHeight → double
-
final
- rowPaddingHorizontal → double
-
final
- rowPaddingVertical → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrimOpacity → double
-
final
- springStrength → double
-
final
-
final
- surfaceOpacity → double
-
final
- travelArc → double
-
final
Methods
-
copyWith(
{double? surfaceOpacity, double? borderOpacity, double? borderWidth, Color? borderColor, double? backdropBlurSigma, double? parentScale, double? scrimOpacity, double? maxHeight, double? iconSize, double? pressExpansion, double? springStrength, double? travelArc, double? rowPaddingVertical, double? rowPaddingHorizontal, double? rowMinHeight, Duration? closeDuration, }) → UiMenuTokens -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
UiMenuTokens a, UiMenuTokens b, double t) → UiMenuTokens
Constants
- defaults → const UiMenuTokens