UiMessageScrollerItem class

Annotations

Constructors

UiMessageScrollerItem({required String id, required Widget child, bool isOutgoing = false})
const

Properties

child Widget
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isOutgoing bool
Whether this item was authored by the current user.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited