UiMessageUtilityAction class

Annotations

Constructors

UiMessageUtilityAction({required Object id, required IconData icon, required String label, required VoidCallback onPressed, UiIntent intent = UiIntent.ghost, bool enabled = true})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
id Object
final
intent UiIntent
final
label String
final
onPressed VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited