UiMutationState class

Constructors

UiMutationState({UiMutationStatus status = UiMutationStatus.idle, Object? error, StackTrace? stackTrace})
const

Properties

error Object?
final
hashCode int
The hash code for this object.
no setteroverride
isFailure bool
no setter
isIdle bool
no setter
isPending bool
no setter
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
final
status UiMutationStatus
final

Methods

copyWith({UiMutationStatus? status, Object? error, StackTrace? stackTrace}) UiMutationState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override