UiNavigationDrawerDestination class

Selectable destination rendered by UiNavigationDrawer.

Constructors

UiNavigationDrawerDestination({required String label, required VoidCallback onPressed, Widget? icon, bool selected = false, Widget? badge, int? badgeCount, double iconSize = 22})
const

Properties

badge Widget?
final
badgeCount int?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
iconSize double
final
label String
final
onPressed VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited