UiNavigationRailGeometry class

Size and spacing configuration for UiNavigationRail.

The defaults are tuned for a floating rail whose collapsed width leaves enough room for floating-window chrome while keeping the destination affordances optically centered.

Constructors

UiNavigationRailGeometry({double expandedOuterWidth = 260, double collapsedOuterWidth = 84, double outerMargin = 12, double itemPadding = 10, double headerHeight = 40, double destinationHeight = 40, double maxPanelHeight = double.infinity, int minVisibleDestinations = 3, double expandedHeaderTopPadding = 4, double collapsedHeaderTopPadding = 4, double headerEndPadding = 8, double headerToggleExtent = 34, double headerToggleIconSize = 18, double collapsedChromeTopPadding = 34, double collapsedChromeMaxHeightExtra = 12})
const

Properties

collapsedChromeMaxHeightExtra double
final
collapsedChromeTopPadding double
final
collapsedHeaderTopPadding double
final
collapsedItemLeadingInset double
no setter
collapsedOuterWidth double
final
collapsedPanelWidth double
no setter
destinationExtent double
Layout extent of a destination including its accessible tap target.
no setter
destinationHeight double
final
expandedHeaderTopPadding double
final
expandedOuterWidth double
final
expandedPanelWidth double
no setter
hashCode int
The hash code for this object.
no setterinherited
headerEndPadding double
final
headerHeight double
final
headerToggleExtent double
final
headerToggleIconSize double
final
itemPadding double
final
maxPanelHeight double
final
minVisibleDestinations int
final
outerMargin double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

headerTopPadding({required bool collapsed, required bool hasFloatingWindowChrome}) double
labelProgressForRailProgress(double railProgress, {required bool collapsed}) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
panelWidthFor(double outerWidth) double
railProgressForPanelWidth(double panelWidth) double
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const UiNavigationRailGeometry