scrollFade property
Applies a soft top/bottom edge mask to the page body.
This is intended for pages whose scrollable content moves below floating chrome. Top/bottom bars are not masked.
Implementation
final bool scrollFade;
Applies a soft top/bottom edge mask to the page body.
This is intended for pages whose scrollable content moves below floating chrome. Top/bottom bars are not masked.
final bool scrollFade;