scrollFadeWideExtent property
Top fade distance used on tablet and desktop viewports.
A shorter wide-screen fade prevents large navigation titles from veiling the first content row after a persistent rail reduces the content pane.
Implementation
final double scrollFadeWideExtent;