label property
Plain-text label. Used by the collapsed trigger, the default row label, and accessibility announcements.
Implementation
final String label;
Plain-text label. Used by the collapsed trigger, the default row label, and accessibility announcements.
final String label;