UiShadowTokens class

Elevation shadows tuned for shadcn-style surfaces.

Annotations

Constructors

UiShadowTokens({List<BoxShadow> none = const <BoxShadow>[], List<BoxShadow> sm = const <BoxShadow>[BoxShadow(color: Color(0x0D000000), blurRadius: 2, offset: Offset(0, 1))], List<BoxShadow> md = const <BoxShadow>[BoxShadow(color: Color(0x1A000000), blurRadius: 6, offset: Offset(0, 4)), BoxShadow(color: Color(0x0F000000), blurRadius: 2, offset: Offset(0, 2))], List<BoxShadow> lg = const <BoxShadow>[BoxShadow(color: Color(0x1A000000), blurRadius: 16, offset: Offset(0, 10)), BoxShadow(color: Color(0x0F000000), blurRadius: 6, offset: Offset(0, 4))]})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lg List<BoxShadow>
final
md List<BoxShadow>
final
none List<BoxShadow>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm List<BoxShadow>
final

Methods

copyWith({List<BoxShadow>? none, List<BoxShadow>? sm, List<BoxShadow>? md, List<BoxShadow>? lg}) UiShadowTokens
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

standard → const UiShadowTokens