UiSheetSnap class

Snap-point model for UiSheet presentation.

Annotations

Constructors

UiSheetSnap.fit()
const
UiSheetSnap.fraction(double value)
const
UiSheetSnap.full()
const
UiSheetSnap.half()
const

Properties

fraction double?
final
hashCode int
The hash code for this object.
no setterinherited
isFit bool
no setter
kind UiSheetSnapKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited