expandedLayout property
Width policy once the hidden actions are shown in wide layouts.
Implementation
final UiSmartActionGroupExpandedLayout expandedLayout;
Width policy once the hidden actions are shown in wide layouts.
final UiSmartActionGroupExpandedLayout expandedLayout;