UiStickyRegionSurface enum

Surface treatment for UiSliverStickyRegion.

Inheritance
Available extensions

Values

adaptive → const UiStickyRegionSurface

Glass without a rail and a quiet solid page surface beside a rail.

edgeFade → const UiStickyRegionSurface

Token surface with a trailing edge fade and no backdrop sampling.

glass → const UiStickyRegionSurface

Compatibility alias for the former backdrop-blurred treatment.

solid → const UiStickyRegionSurface

Opaque page-background surface.

transparent → const UiStickyRegionSurface

No painted surface. Best for non-overlapping or floating content.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UiStickyRegionSurface>
A constant List of the values in this enum, in order of their declaration.