UiTailwindPalette class abstract final

Tailwind-compatible sRGB scales, also familiar to shadcn developers.

Tailwind v4 publishes colors in OKLCH. These sRGB values intentionally use the widely adopted hex-compatible scale so Flutter developers can migrate existing color references without adding a color-space conversion layer.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amber → const UiColorScale
blue → const UiColorScale
cyan → const UiColorScale
emerald → const UiColorScale
fuchsia → const UiColorScale
gray → const UiColorScale
green → const UiColorScale
indigo → const UiColorScale
lime → const UiColorScale
neutral → const UiColorScale
orange → const UiColorScale
pink → const UiColorScale
purple → const UiColorScale
red → const UiColorScale
rose → const UiColorScale
sky → const UiColorScale
slate → const UiColorScale
stone → const UiColorScale
teal → const UiColorScale
violet → const UiColorScale
yellow → const UiColorScale
zinc → const UiColorScale