UiThemeData class

Helpers for building framework-neutral UiThemeTokens.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dark({UiColorTokens? colors, UiSpacingTokens? spacing, UiRadiusTokens? radius, UiShadowTokens? shadows, UiTypographyTokens? typography, UiMotionTokens? motion, UiEffectsTokens? effects}) UiThemeTokens
Dark theme with neutral Open UI Kit tokens.
fromBrand(UiBrand brand, {Brightness brightness = Brightness.light, UiSpacingTokens? spacing, UiRadiusTokens? radius, UiShadowTokens? shadows, UiTypographyTokens? typography, UiMotionTokens? motion, UiEffectsTokens? effects}) UiThemeTokens
Build UiThemeTokens from a UiBrand runtime config.
light({UiColorTokens? colors, UiSpacingTokens? spacing, UiRadiusTokens? radius, UiShadowTokens? shadows, UiTypographyTokens? typography, UiMotionTokens? motion, UiEffectsTokens? effects}) UiThemeTokens
Light theme with neutral Open UI Kit tokens.
of(BuildContext context) UiThemeTokens
Shorthand for resolving tokens from the nearest UiTheme.