UiTimelineEvent class

Immutable content model for one UiTimeline entry.

Annotations

Constructors

UiTimelineEvent({required Object id, required DateTime at, required String title, UiTimelineActor? actor, String? description, String? messageTitle, String? messageBody, List<UiTimelineChange> changes = const [], List<UiTimelineTag> tags = const [], UiTimelineTone tone = UiTimelineTone.neutral, Widget? icon, UiTimelineMarker marker = UiTimelineMarker.automatic})
const

Properties

actor UiTimelineActor?
final
at DateTime
final
changes List<UiTimelineChange>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
final
id Object
final
marker UiTimelineMarker
final
messageBody String?
final
messageTitle String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<UiTimelineTag>
final
title String
final
tone UiTimelineTone
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited