UiContainerBackdropStyle enum
How the route behind an iOS-style container transform is separated from the expanding surface.
Values
- adaptive → const UiContainerBackdropStyle
-
Use blur when the active effects budget allows it, otherwise use tint.
- blur → const UiContainerBackdropStyle
-
Blur the exposed route and add a subtle tint for contrast.
- tint → const UiContainerBackdropStyle
-
Draw only an animated translucent color. This avoids backdrop sampling.
- none → const UiContainerBackdropStyle
-
Do not draw a backdrop treatment.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UiContainerBackdropStyle> - A constant List of the values in this enum, in order of their declaration.