UiFormattedTextRule class
A delimiter pair and the visual treatment of the text it encloses.
Constructors
- UiFormattedTextRule({required String id, required String open, String? close, required UiFormattedTextStyleBuilder styleBuilder, String? semanticLabel})
-
const
Properties
- close → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- open → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- styleBuilder → UiFormattedTextStyleBuilder
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited