UiMessageScrollerController class
Imperative access to a UiMessageScroller's live-edge state.
- Inheritance
-
- Object
- ChangeNotifier
- UiMessageScrollerController
Constructors
Properties
- firstUnseenMessageId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasUnreadMarker → bool
-
no setter
- isAtLiveEdge → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unseenCount → int
-
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dismissUnreadMarker(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
jumpToFirstUnseen(
{bool animated = true}) → Future< bool> -
jumpToLatest(
{bool animated = true}) → Future< void> -
jumpToMessage(
String id, {bool animated = true}) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited