isOutgoing property
Whether this item was authored by the current user.
A newly appended outgoing item dismisses an active unread boundary.
Implementation
final bool isOutgoing;
Whether this item was authored by the current user.
A newly appended outgoing item dismisses an active unread boundary.
final bool isOutgoing;