UiPageBodyInsetsAspect enum
Resting edge insets that page body scrollables should include in their content padding when UiPageScaffold.scrollFadeUsesSafeArea is enabled.
The scaffold itself stays visually full-bleed. Scrollable page patterns use these values to keep content clear of hardware insets and, beside a persistent rail, the top scroll-fade region while the fade remains painted at the physical edges.
Values
- top → const UiPageBodyInsetsAspect
- right → const UiPageBodyInsetsAspect
- bottom → const UiPageBodyInsetsAspect
- left → const UiPageBodyInsetsAspect
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UiPageBodyInsetsAspect> - A constant List of the values in this enum, in order of their declaration.