UiPlatformCapabilities class
Constructors
- UiPlatformCapabilities({MethodChannel? channel, Duration cacheDuration = const Duration(milliseconds: 250)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
windowModeChanges
→ Stream<
UiWindowMode> -
Native window-mode transitions, including position-only scene moves that
do not change Flutter's viewport metrics.
no setter
Methods
-
currentWindowMode(
{bool forceRefresh = false}) → Future< UiWindowMode> -
invalidateCache(
) → void -
invokeFeature<
T> (String feature, {Map< String, Object?> arguments = const <String, Object?>{}}) → Future<T?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snapshot(
{bool forceRefresh = false}) → Future< UiPlatformSnapshot> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
final
Constants
- channelName → const String