Radix Colors light-theme solid anchors (step 9).
Radix's complete 12-step scales encode usage as well as hue. Use this compatibility namespace when migrating a solid accent, then map it to an Open UI semantic token. It intentionally does not pretend step numbers are interchangeable with Tailwind shade numbers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- amber → const Color
- blue → const Color
- bronze → const Color
- brown → const Color
- crimson → const Color
- cyan → const Color
- gold → const Color
- grass → const Color
- gray → const Color
- green → const Color
- indigo → const Color
- iris → const Color
- jade → const Color
- lime → const Color
- mauve → const Color
- mint → const Color
- olive → const Color
- orange → const Color
- pink → const Color
- plum → const Color
- purple → const Color
- red → const Color
- ruby → const Color
- sage → const Color
- sand → const Color
- sky → const Color
- slate → const Color
- teal → const Color
- tomato → const Color
- violet → const Color
- yellow → const Color