UiSelectPlacement enum
Placement strategy used when the dropdown opens.
Values
- auto → const UiSelectPlacement
-
Default: open below when there's room, otherwise above.
- anchorSelected → const UiSelectPlacement
-
Anchor the selected item directly over the trigger, like a native picker. Falls back to auto when there is no selected value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UiSelectPlacement> - A constant List of the values in this enum, in order of their declaration.