UiTextVariant enum
Semantic text roles mapped to UiTypographyTokens.
Values
- displayXl → const UiTextVariant
- displayLg → const UiTextVariant
- displayMd → const UiTextVariant
- title → const UiTextVariant
- heading → const UiTextVariant
- subheading → const UiTextVariant
- bodyLg → const UiTextVariant
- body → const UiTextVariant
- bodySm → const UiTextVariant
- label → const UiTextVariant
- labelSm → const UiTextVariant
- caption → const UiTextVariant
- micro → const UiTextVariant
- mono → const UiTextVariant
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UiTextVariant> - A constant List of the values in this enum, in order of their declaration.