UiTimeValue class
24-hour clock value (hour 0..23, minute 0..59).
- Annotations
Constructors
- UiTimeValue({required int hour, required int minute})
-
const
- UiTimeValue.fromDateTime(DateTime value)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hour → int
-
final
- minute → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalMinutes → int
-
no setter
Methods
-
formatted12(
) → String -
formatted24(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override