UiTypographyTokens class
Semantic typography scale.
- Annotations
Constructors
- UiTypographyTokens({required TextStyle displayLg, required TextStyle displayMd, required TextStyle heading, required TextStyle subheading, required TextStyle bodyLg, required TextStyle body, required TextStyle bodySm, required TextStyle label, required TextStyle caption, required TextStyle mono})
-
const
Properties
- body → TextStyle
-
final
- bodyLg → TextStyle
-
final
- bodySm → TextStyle
-
final
- caption → TextStyle
-
final
- displayLg → TextStyle
-
final
- displayMd → TextStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → TextStyle
-
final
- label → TextStyle
-
final
- mono → TextStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subheading → TextStyle
-
final
Methods
-
copyWith(
{TextStyle? displayLg, TextStyle? displayMd, TextStyle? heading, TextStyle? subheading, TextStyle? bodyLg, TextStyle? body, TextStyle? bodySm, TextStyle? label, TextStyle? caption, TextStyle? mono}) → UiTypographyTokens -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- standard → UiTypographyTokens
-
final